/* 
**
**  remedial - a GUI front-end for avifile
**  Copyright (C) 2002  Paul Dwerryhouse <paul@dwerryhouse.com.au>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*/

extern "C" {
#include <stdio.h>
#include <expat.h>
#include <string.h>
}
#include "configfile.h"

#define BUFFSIZE	8192
#define MAX_PRESETS	100

enum { RM_REMEDIAL, RM_PRESETS, RM_PRESET, RM_PRESETNUM, RM_PRESETURL, 
	RM_PRESETNAME };

char Buff[BUFFSIZE];
struct preset presets[MAX_PRESETS];

int lastelement;

int presetnum;
char *preseturl;
char *presetname;

void
start(void *data, const char *el, const char **attr) {
  int i;

  if (!strcmp(el,"remedial")) lastelement = RM_REMEDIAL;
  if (!strcmp(el,"presets")) lastelement = RM_PRESETS;
  if (!strcmp(el,"preset")) lastelement = RM_PRESET;
  if (!strcmp(el,"presetnum")) lastelement = RM_PRESETNUM;
  if (!strcmp(el,"preseturl")) lastelement = RM_PRESETURL;
  if (!strcmp(el,"presetname")) lastelement = RM_PRESETNAME;

//  for (i = 0; attr[i]; i += 2) {
//    printf(" %s='%s'", attr[i], attr[i + 1]);
//  }

}  /* End of start handler */

void
end(void *data, const char *el) {
  if (!strcmp(el,"preset")) {
#ifdef DEBUG
	  fprintf(stderr,"%s %s\n",presetname,preseturl);
#endif
	  if (presetnum > MAX_PRESETS) {
		  free(preseturl);
		  free(presetname);
	  } else {
	  	presets[presetnum].preseturl = preseturl;
	  	presets[presetnum].presetname = presetname;
#ifdef DEBUG
	  	fprintf(stderr,"%d %s\n",presetnum,preseturl);
#endif
	  }
  }
}  /* End of end handler */

void text(void *data,const XML_Char *s,int len) {
	if (lastelement == RM_PRESETURL) {
		preseturl = (char *) malloc (sizeof(char)*(len+1));
		strncpy(preseturl,s,len);
		preseturl[len]=0;
		lastelement=0;
	} else if (lastelement == RM_PRESETNAME) {
		presetname = (char *) malloc (sizeof(char)*(len+1));
		strncpy(presetname,s,len);
		presetname[len]=0;
		lastelement=0;
	} else if (lastelement == RM_PRESETNUM) {
		presetnum=atoi(s);
		lastelement=0;
	}
}

struct preset *readconf(char *filename) {

  FILE *config;
  
  for(int i=0; i<MAX_PRESETS; i++) {
	  presets[i].presetname=0;
	  presets[i].preseturl=0;
  }

  if (!(config = fopen(filename,"r"))) {
	  return 0;
  }

  XML_Parser p = XML_ParserCreate(NULL);
  if (! p) {
    fprintf(stderr, "Couldn't allocate memory for parser\n");
    exit(-1);
  }

  XML_SetElementHandler(p, start, end);
  XML_SetCharacterDataHandler(p, text);

  for (;;) {
    int done;
    int len;

    len = fread(Buff, 1, BUFFSIZE, config);
    if (ferror(config)) {
      fprintf(stderr, "Read error\n");
      exit(-1);
    }
    done = feof(config);

    if (! XML_Parse(p, Buff, len, done)) {
      fprintf(stderr, "Parse error at line %d:\n%s\n",
	      XML_GetCurrentLineNumber(p),
	      XML_ErrorString(XML_GetErrorCode(p)));
      exit(-1);
    }

    if (done)
      break;
  }
  fclose(config);

  return presets;

}  /* End of main */

