/* 
**
**  remedial - a GUI front-end for avifile
**  Copyright (C) 2002  Paul Dwerryhouse <paul@dwerryhouse.com.au>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*/


#include <videodecoder.h>
#include <aviplay.h>
#include <avifile.h>
#include <creators.h>

extern "C" {
#include <unistd.h>
#include <fcntl.h>
#include <stdio.h>
#include <stdlib.h>
#ifdef HAVE_GETOPT_H
#include <getopt.h>
#endif
}

#include <cstdio>
#include <qapplication.h>
#include <qtimer.h>
#include "qtgui.h"
#include "qtdock.h"
#include "player.h"

extern char *optarg;

void usage(char *);
void version(void);

int main(int argc,char **argv) {

	int c,preset=-1,dock=0;

	while( (c=getopt(argc,argv,"hvdp:")) != -1)  {
		switch(c) {
			case 'p':	preset=atoi(optarg);
					break;
			case 'v': 	version();
					exit(0);
			case 'd':	dock=1;
					break;
			case 'h': 	/* Fallthrough */
			default:	usage(argv[0]);
					break;
		}
	}

	version();

	QApplication a( argc, argv );

	Player *player = new Player();

	if (dock) {
		QtDock dockw;

		dockw.setPlayer(player);
		dockw.show();
		a.setMainWidget( &dockw);
		return a.exec();
	}

	if (preset >=0 ) {
		player->setPreset(preset);
	}
	else if (argc == 2) {
		player->setFile(argv[1]);
	}

	QtGui widget;
	widget.setPlayer(player);
	widget.resize(315,256);


	a.setMainWidget( &widget );
	widget.show();
	return a.exec();


}

void usage(char *prog) {
        printf("Usage: %s [-v] | [-h] | [-d] | [-p <preset>] | [filename]\n",
				prog);
        exit(0);
}

void version(void) {
	printf( "Remedial version " VERSION ", Copyright (C) 2002, 2003  "
			"Paul Dwerryhouse\n"
	"Remedial comes with ABSOLUTELY NO WARRANTY.\n"
	"This is free software, and you are welcome to redistribute it\n"
	"under the conditions of the GNU General Public License, "
	"version 2.0.\n"
	"Please see the COPYING file supplied with this program for "
	"details.\n");
}
