/* 
**
**  remedial - a GUI front-end for avifile
**  Copyright (C) 2002  Paul Dwerryhouse <paul@dwerryhouse.com.au>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*/


extern "C" {
#include <stdio.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <sys/ioctl.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
}

#include <aviplay.h>
#include "player.h"
#include "configfile.h"

// The avifile volume controlling API doesn't seem to work at the moment
// so we use the following code instead. Unfortunately, it will only
// work with OSS/ALSA

#define BROKEN_AVIFILE_MIXER

#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
#include <linux/soundcard.h>
#endif
#endif

#define AVM_COMPATIBLE

#define FILE "mms://media4.abc.net.au/triplej"

#define GLOBALCFG SYSCONFDIR "/remedial.xml"
#define CFGFILE "/.remedial/remedial.xml"

#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
int mixer;
#endif
#endif

char *default_presets[] = { 
	"mms://media4.abc.net.au/triplej",
	"mms://winmedialive.webhosting.bigpond.com/UCS-wh_nova100",
	"mms://winmedialive.webhosting.bigpond.com/UCS-wh_nova960",
	"mms://msn02.cableandwireless.be/stubrulo"
};

Player::Player() {
	char *name;
	int len;

	file = FILE;
	player=0;
	muted=0;
	autostart=0;

	name = strdup(getenv("HOME"));
	len = strlen(name);
	name = (char *) realloc (name, (len + strlen(CFGFILE) + 1) 
						* sizeof(char));
	strcat(name,CFGFILE);

	if (!(presets = readconf(name))) {
		if (! (presets = readconf(GLOBALCFG))) {
			if (! (presets = readconf("./remedial.xml"))) {
				fprintf(stderr,"Can't find config file\n");
				exit(1);
			}
		}
	}

#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
	// Don't close it! It makes avifile segfault.
	mixer = open("/dev/mixer",O_RDWR);
#endif
#endif
}

int Player::start() {
	avm::vector<avm::string> urls;
	player = avm:: CreateAviPlayer (file,0,0,0);

#if !defined(NETBSD_HACK) && !defined(SOLARIS_HACK)
	player->Set(player->USE_HTTP_PROXY,&useproxy);
	player->Set(player->HTTP_PROXY,proxy);
#endif

	while (!player->IsOpened()) {
		sleep(1);
	}

	if (player->IsRedirector()) {
		player->GetURLs(urls);

		player = avm:: CreateAviPlayer (urls[0],0,0,0);
		while (!player->IsOpened()) {
			sleep(1);
		}
	}

	// avm::vector<avm::IVideoRenderer *>x;
	// player->SetVideoRenderers(x);
	printf("OK: Opened\n");
	return 1;
}

void Player::play() {

	if (!player->IsPlaying()) 
		player->Start();
	else
		player->Play();
	
}

void Player::stop() {
	player->Stop();
}

void Player::buffer() {
	double x;
	avm::IAviPlayer::State state;
	state = player->GetState(&x);
	if (state == avm::IAviPlayer::Buffering) 
		printf("%f\n", (float) x);
}

void Player::setProxy(bool enabled,const char *newproxy) {
	useproxy = enabled;
	proxy = (char *) newproxy;
}

void Player::mute() {

	if (!player) return;
	if (!player->IsPlaying()) return;

	if (muted) {
#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
		ioctl(mixer,MIXER_WRITE(SOUND_MIXER_VOLUME),&volume);
#endif
#else
		player->Set(player->AUDIO_VOLUME,&volume,0);
#endif
		muted=0;
	} else {
		unsigned int newvol = 0;
#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
		ioctl(mixer,MIXER_READ(SOUND_MIXER_VOLUME),&volume);
		ioctl(mixer,MIXER_WRITE(SOUND_MIXER_VOLUME),&newvol);
#endif
#else
		player->Get(player->AUDIO_VOLUME,&volume,0);
		player->Set(player->AUDIO_VOLUME,&newvol,0);
#endif
		muted=1;
	}
}

void Player::setvol(int vol) {

	unsigned int setvol;

#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
	setvol = (vol << 8) + vol;
	ioctl(mixer,MIXER_WRITE(SOUND_MIXER_VOLUME),&setvol);
#endif
#else
	setvol = (10000 * vol) / 100;
	player->Set(player->AUDIO_VOLUME,&volume,0);
#endif
}

unsigned int Player::getvol() {

	unsigned int volume;

#ifdef BROKEN_AVIFILE_MIXER
#ifdef HAVE_LINUX_SOUNDCARD_H
	unsigned int left, right;
	ioctl(mixer,MIXER_READ(SOUND_MIXER_VOLUME),&volume);
	right = volume & 255;
	left = volume >> 8;
	volume = (left + right) / 2 ;
#endif
#else
	player->Get(player->AUDIO_VOLUME,&volume,0);  // XXX fix!
#endif

	return volume;
}

void Player::choosepreset(int preset) {
	file=presets[preset].preseturl;
}

char *Player::getname(int preset) {
	return presets[preset].presetname;
}

int Player::status() {
	double percent;
	return (int) player->GetState(&percent);
}
