/* 
**
**  remedial - a GUI front-end for avifile
**  Copyright (C) 2002  Paul Dwerryhouse <paul@dwerryhouse.com.au>
**
**  This program is free software; you can redistribute it and/or modify
**  it under the terms of the GNU General Public License as published by
**  the Free Software Foundation; either version 2 of the License, or
**  (at your option) any later version.
**
**  This program is distributed in the hope that it will be useful,
**  but WITHOUT ANY WARRANTY; without even the implied warranty of
**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**  GNU General Public License for more details.
**
**  You should have received a copy of the GNU General Public License
**  along with this program; if not, write to the Free Software
**  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
**
*/


#include <qapplication.h>
#include <qvbox.h>
#include <qhbox.h>
#include <qpushbutton.h>
#include <qmenubar.h>
#include <qpopupmenu.h>
#include <qtimer.h>
#include <qlabel.h>
#include <qpixmap.h>
#include <qiconset.h>
#include <qtoolbar.h>
#include <qslider.h>
#include <qstatusbar.h>
#include <qhbuttongroup.h>
#include <qmessagebox.h>
#include <qtooltip.h> 
#include <qspinbox.h> 
#include <qcheckbox.h> 
#include <qlineedit.h> 

extern "C" {
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>

#include <stdlib.h>
#include <time.h>
}

#include "qtgui.h"
#include "qtgui.moc"
#include "qtoptionsdialog.h"
#include "play.xpm"
#include "stop.xpm"
#include "pause.xpm"
#include "mute.xpm"
#include "remedial.xpm"

QtGui::QtGui(QWidget *parent, const char *name)
	: QVBox(parent,name) {

	sig_start=playing=sig_stop=0;

	timer = new QTimer();


	QPopupMenu *filemenu = new QPopupMenu();
	//filemenu->insertItem("Open",0);
	//filemenu->insertItem("Close",1);
	filemenu->insertItem("Quit",2);
	connect(filemenu,SIGNAL(activated(int)),this,SLOT(do_filemenu(int)));

	QPopupMenu *playmenu = new QPopupMenu();
	playmenu->insertItem("Play",0);
	playmenu->insertItem("Stop",1);
	//playmenu->insertItem("Mute",2);
	//playmenu->insertItem("Next",3);
	//playmenu->insertItem("Previous",4);
	connect(playmenu,SIGNAL(activated(int)),this,SLOT(do_playmenu(int)));

	QPopupMenu *toolsmenu = new QPopupMenu();
	toolsmenu->insertItem("Options",0);
	toolsmenu->insertItem("Save Settings (not functional)",1);
	connect(toolsmenu,SIGNAL(activated(int)),this,SLOT(do_toolsmenu(int)));

	QPopupMenu *helpmenu = new QPopupMenu();
	//helpmenu->insertItem("Manual",0);
	helpmenu->insertItem("About",1);
	connect(helpmenu,SIGNAL(activated(int)),this,SLOT(do_helpmenu(int)));

	QMenuBar *mb = new QMenuBar(this);
	mb->insertItem("File",filemenu);
	mb->insertItem("Play",playmenu);
	mb->insertItem("Tools",toolsmenu);
	mb->insertItem("Help",helpmenu);

	QHBox *buttonbar = new QHBox (this);
	QHBox *viewbar = new QHBox (this);
	QHBox *controlbar = new QHBox (this);

	controlbar->setSpacing(5);
	controlbar->setMargin(5);

	QHButtonGroup *presetbar = new QHButtonGroup(this);
	QHBox *statusbar = new QHBox (this);

	// QPushButton *play = new QPushButton("Play", buttonbar);
	// QPushButton *stop = new QPushButton("Stop", buttonbar);
	
	QPushButton *play = new QPushButton((QPixmap(play_xpm)), "", buttonbar);
	QPushButton *stop = new QPushButton((QPixmap(stop_xpm)), "", buttonbar);
	QPushButton *pause = new QPushButton((QPixmap(pause_xpm)), "", buttonbar);

	QToolTip::add( play, "Play" );
	QToolTip::add( stop, "Stop" );
	QToolTip::add( pause, "Pause" );

	play->setFlat(true); play->setFixedSize(30,30);
	stop->setFlat(true); stop->setFixedSize(30,30);
	pause->setFlat(true); pause->setFixedSize(30,30);

	connect(play,SIGNAL(clicked()),this,SLOT(start()));
	connect(stop,SIGNAL(clicked()),this,SLOT(stop()));

	QLabel *logo = new QLabel(viewbar);

	logo->setPixmap(QPixmap(remedial_xpm));

	QSlider *position = new QSlider(0,100,1,0,QSlider::Horizontal,buttonbar);
	QToolTip::add( position, "Position (currently unimplemented)" );

	presetpage = new QSpinBox(0,9,1,controlbar,0);
	QToolTip::add( presetpage, "Set Preset Page" );
	connect(presetpage,SIGNAL(valueChanged(int)),
				this,SLOT(changePage(int)));

	volume = new QSlider(0,100,2,0,QSlider::Horizontal,controlbar);
	volume->setValue(player->getvol());
	QToolTip::add( volume, "Volume" );
	connect(volume,SIGNAL(valueChanged(int)),this,SLOT(setvol(int)));

	QPushButton *mute = new QPushButton((QPixmap(mute_xpm)), "", controlbar);
	QToolTip::add( mute, "Mute" );

	mute->setFlat(true); mute->setFixedSize(30,30);

	connect(mute,SIGNAL(clicked()),this,SLOT(mute()));

	//position->setTickmarks(QSlider::Below);


	int i;
	for(i=0;i<10;i++) {
		char num[2];
		sprintf(num,"%d",i);
		presets[i] = new QPushButton(num, presetbar);
	}
	connect(presetbar,SIGNAL(clicked(int)),this,SLOT(preset(int)));

	dialog = new OptionsDialog(0,"optionsdialog",1);
	connect(dialog,SIGNAL(applyButtonPressed()),this,
			SLOT(do_setoptions()));

	status = new QLabel("Status", statusbar);
	runtime = new QLabel("0", statusbar);
	runtime->setAlignment(QLabel::AlignRight);
	connect(timer,SIGNAL(timeout()),this,SLOT(timerslot()));
	timer->start(500);
}

void QtGui::start() {
	if (playing) { 
		player->stop();
		playing=0;
	}
	sig_start=1;
}

void QtGui::stop() {
	//timer->stop();
	//player->stop();
	//status->setText("Stopped");
	sig_stop=1;
}

void QtGui::do_filemenu(int itemid) {
	switch(itemid) {
		case 2: quit();
	}
}

void QtGui::do_playmenu(int itemid) {
	switch(itemid) {
		case 0: start();
			break;
		case 1: stop();
			break;
	}
}

void QtGui::do_toolsmenu(int itemid) {
	
	switch(itemid) {
		case 0: dialog->show();
			break;
	}
}

void QtGui::do_helpmenu(int itemid) {
	switch(itemid) {
		case 1: QMessageBox::information(this,"remedial",
					player->about(), "Ok");
			break;
	}
}

void QtGui::do_setoptions() {
	QToolTip::setGloballyEnabled( dialog->getToolTipsState() );
	player->setProxy(dialog->getUseProxy(),dialog->getProxyHost());
}

void QtGui::quit() {
	if (timer->isActive()) timer->stop();
	exit(0);
}

void QtGui::mute() {
	player->mute();
}

void QtGui::setvol(int vol) {
	player->setvol(vol);
}

void QtGui::preset(int bnum) {
	char *str;
	int presetnum;

	if (playing) { 
		player->stop();
		playing=0;
	}
	presetnum = bnum+(presetpage->value()*10);

	fprintf(stderr,"=== %d\n",presetnum);
	player->choosepreset(presetnum);

	str=strdup("remedial: ");
	str=(char *) realloc(str, sizeof(char) * (strlen(str)+
				strlen(player->getname(presetnum) + 1 )));
	strcat(str,player->getname(presetnum));
	setCaption(str);
	free(str);

	start();
}

void QtGui::setPlayer(Player *p) { 
	player = p; 
	int i;
	for(i=0;i<10;i++) {
		QToolTip::add( presets[i], player->getname(i) );
	}
	if (player->getautostart()) sig_start=1;
}

void QtGui::changePage(int value) {
	int i,page;
	page = value;
	for(i=0;i<10;i++) {
		QToolTip::remove( presets[i]); 
		if (player->getname(page*10+i)) {
			char str[3];
			QToolTip::add( presets[i], player->getname(page*10+i));
			presets[i]->setEnabled(1);

			sprintf(str,"%d",i);
			presets[i]->setText(str);
		} else {
			presets[i]->setEnabled(0);
			presets[i]->setText(" ");
		}
	}
}

void QtGui::timerslot() {
	if (sig_start) {
		if (player->start()) {
			starttime = time(0);
			sig_start=0; playing=1;
		}
	} 
	if (playing) { 
		char *statusstr;
		int sec,min;
		int state;
		char timestr[10];
		player->play();

		state = player->status();
		
		switch(state) {
			case 0: statusstr="Opening..."; break;
			case 1: statusstr="Buffering..."; break;
			case 2: statusstr="Playing"; break;
			case 3: statusstr="Stopped"; break;
			case 4: statusstr="Paused"; break;
			case 5: statusstr="Invalid"; 
				playing=0;
				break;
			default: statusstr="Unknown"; break;
		}
			
	
		status->setText(statusstr);
	
		sec = time(0)-starttime;
		min = (int) (sec / 60);
		sec = sec - min*60;
	
		sprintf(timestr,"%d.%02d",min,sec);
		runtime->setText(timestr);
	
	}
	if (sig_stop) { 
		player->stop();
		playing=0;
		sig_stop=0;
	}

	volume->setValue(player->getvol());
}

